//
//  ItemPersonView.swift
//  Jel
//
//  Created by zerocool on 1/13/24.
//

import SwiftUI
import JellyfinKit

struct ItemPersonView: View {
  @EnvironmentObject var jellyfinClient: JellyfinClientController
  
  var item: BaseItemDto
  
  @State var items: [BaseItemDto]?
  
  var body: some View {
    VStack(alignment: .leading) {
      Text(item.name ?? "---")
        .font(.title)
        .padding()
      
      if let overview = item.overview {
        Text(overview)
          .padding([.horizontal, .bottom])
      }
      
      if let items = items {
        // TODO: Extract to view to maintain DRY
        let movies = items.filter({$0.type == .movie})
        if movies.count > 0 {
          Text("Movies")
            .font(.title2)
            .padding(.horizontal)
          ScrollView(.horizontal) {
            LazyHStack {
              ForEach(movies) {movie in
                Text(movie.name ?? "")
              }
            }
            .padding(.horizontal)
          }
        }
        
        let shows = items.filter({$0.type == .series})
        if shows.count > 0 {
          Text("Shows")
            .font(.title2)
            .padding(.horizontal)
          ScrollView(.horizontal) {
            LazyHStack {
              ForEach(shows) {show in
                Text(show.name ?? "")
              }
            }
            .padding(.horizontal)
          }
        }
      }
    }
    .onAppear {
      Task {
        let parameters = Paths.GetItemsParameters(
          isRecursive: true,
          personIDs: [item.id ?? ""]
        )
        let request = Paths.getItems(parameters: parameters)
        
        do {
          let res = try await jellyfinClient.send(request)
          items = res.value.items ?? []
        } catch {}
      }
    }
  }
}

//#Preview {
//    ItemPersonView()
//}
